@@ -13,7 +13,7 @@ from .data import conan_profiles
 
 def to_rapid_os(os_name: str) -> str | None:
     if os_name == "Windows":
-        return "windows"
+        return base.OS_WINDOWS
     return None
 
 
@@ -27,7 +27,7 @@ def to_rapid_toolchain(conan_compiler: str, version: str) -> str | None:
     return None
 
 
-def _generate_toolchain_msvc_from_conan_vc_vars(vc_vars):
+def _generate_toolchain_manifest_windows_msvc(vc_vars):
     toolchain = {}
 
     generate_sdk_paths = False
@@ -77,7 +77,7 @@ def _generate_toolchain_msvc_from_conan_vc_vars(vc_vars):
     return toolchain
 
 
-def _generate_toolchain_llvm_from_conan_vc_vars(vc_vars):
+def _generate_toolchain_manifest_windows_llvm(vc_vars):
     use_vs_embedded_llvm = False
     if use_vs_embedded_llvm:
         llvm_bin_path = os.path.join(base.sanitize_path(vc_vars["VSINSTALLDIR"]), "VC", "Tools", "Llvm", "x64", "bin")
@@ -87,7 +87,7 @@ def _generate_toolchain_llvm_from_conan_vc_vars(vc_vars):
     toolchain = {
         "compiler_path": os.path.join(llvm_bin_path, "clang++.exe"),
         "compiler_family": "clang",
-        "linker_path": os.path.join(llvm_bin_path, "lld-link.exe"),
+        "linker_path": os.path.join(llvm_bin_path, "lld-link.exe"),  # Must use lld-link on Windows.
         "librarian_path": os.path.join(llvm_bin_path, "llvm-ar.exe"),
         "compiler_extra_files": [],
         "toolchain_include_dirs": base.sanitize_paths(vc_vars["INCLUDE"]),
@@ -100,16 +100,19 @@ def get_toolchain_manifest_filename():
     return "toolchain_gen.json"
 
 
-def generate_toolchain_manifest_from_conan_vc_vars(toolchain_name, vc_vars):
-    if toolchain_name == base.TOOLCHAIN_MSVC16:
-        toolchain = _generate_toolchain_msvc_from_conan_vc_vars(vc_vars)
-    elif toolchain_name == base.TOOLCHAIN_LLVM13:
-        toolchain = _generate_toolchain_llvm_from_conan_vc_vars(vc_vars)
+def generate_toolchain_manifest(os_name, toolchain_name, vc_vars):
+    if os_name == base.OS_WINDOWS:
+        if toolchain_name == base.TOOLCHAIN_MSVC16:
+            toolchain_manifest = _generate_toolchain_manifest_windows_msvc(vc_vars)
+        elif toolchain_name == base.TOOLCHAIN_LLVM13:
+            toolchain_manifest = _generate_toolchain_manifest_windows_llvm(vc_vars)
+        else:
+            raise NotImplementedError("Toolchain '{}' is not implemented.".format(toolchain_name))
     else:
-        raise NotImplementedError("Toolchain '{}' is not implemented.".format(toolchain_name))
+        raise NotImplementedError("Support for host OS '{}' is not implemented.".format(os_name))
 
     toolchain_manifest = {
-        toolchain_name: toolchain
+        toolchain_name: toolchain_manifest
     }
 
     return json.dumps(toolchain_manifest, indent=4)
