@@ -338,7 +338,7 @@ class Workspace:
             return self.fs.getsyspath(self.build_dir_name)
         return f"wks://{self.build_dir_name}"
 
-    def configure(self, *, quick_mode: bool) -> bool:
+    def configure(self) -> bool:
 
         #
         # Load workspace target definitions
@@ -402,6 +402,8 @@ class Workspace:
 
         build_script_filename = self.build_script_emitter.filename()
         build_script_contents = self.build_script_emitter.contents(
+            self._get_source_dir_abs_path(),
+            self._get_configure_dir_abs_path(),
             self._get_build_dir_abs_path(),
             self.toolchains_manifest,
             self.toolchain_settings_provider.get_toolchain_settings(),
@@ -420,7 +422,7 @@ class Workspace:
         return True
 
 
-def open_workspace(wks_dir: str) -> Workspace:
+def open_workspace(wks_dir: str, *, dev_mode=False) -> Workspace:
 
     wks_fs = OSFS(os.path.abspath(wks_dir))
 
@@ -430,7 +432,7 @@ def open_workspace(wks_dir: str) -> Workspace:
         logger=logger,
         process_runner=base.ProcessRunnerDefault(),
         conanfile_path=wks_fs.getsyspath("conanfile.py"),
-        execute_conan=True,
+        execute_conan=not dev_mode,
         base_to_conan_build_type={
             base.BUILD_TYPE_DEBUG: "Debug",
             base.BUILD_TYPE_RELEASE: "Release"
